@@ -18,6 +18,7 @@
 
 #include <QWidget>
 #include <QCheckBox>
+#include <QPushButton>
 
 class QComboBox;
 
@@ -33,11 +34,12 @@ public Q_SLOTS:
      * \brief Starts training
      */
     void start();
+    void slotInitView();
 
 private Q_SLOTS:
     void slotDictionaryChanged();
     void slotDictionarySelected(int index);
-    void slotInitView();
+
 
 private:
     QComboBox *m_ComboDictionary;
@@ -45,6 +47,7 @@ private:
     QComboBox *m_ComboQuestionLang;
     QComboBox *m_ComboAnswerLang;
     QCheckBox *m_checkbox;
+    QPushButton *m_button;
 };
 
 #endif // TRAININGSELECTIONVIEW_H
